@@ -8,8 +8,7 @@ import traceback
 
 from mlpm.app import aidserver
 from mlpm.utility import str2bool
-from sanic import Sanic, request, response
-from sanic.response import json
+from mlpm.response import json_resp
 from werkzeug.datastructures import ImmutableMultiDict
 from werkzeug.utils import secure_filename
 
@@ -19,27 +18,24 @@ def handle_post_solver_train_or_infer(request, upload_folder, request_type):
     data = config.to_dict()
     results = {}
     if 'file' in request.files:
-        filename = secure_filename(request.files["file"][0].name)
+        uploaded_file = request.files['file']
+        filename = secure_filename(uploaded_file.filename)
         # make sure the UPLOAD_FOLDER exsits
         if not os.path.isdir(upload_folder):
             os.makedirs(upload_folder)
         file_abs_path = os.path.join(upload_folder, filename)
-        with open(file_abs_path,"wb") as file:
-            file.write(request.files["file"][0].body)
-        file.close()
+        uploaded_file.save(file_abs_path)
         data['input_file_path'] = file_abs_path
     try:
         if request_type == "infer":
             results = aidserver.solver.infer(data)
-        elif request_type == "train":
-            results = aidserver.solver.train(data)
         else:
             raise NotImplementedError
         if 'delete_after_process' in data:
             if str2bool(data['delete_after_process']):
                 os.remove(file_abs_path)
         print(results)
-        return response.json(results, status=200)
+        return json_resp(results, status=200)
     except Exception as e:
         traceback.print_exc()
-        return response.json({"error": str(e), "code": "500"}, status=500)
+        return json_resp({"error": str(e), "code": "500"}, status=500)
